if length(dbstack)==1
  clear 
  close all
  NumEigs=15; % Number of eigenvalues (and eigenvectors) to find
  N=200;
  sigma='sm';
  E = 21e5; nu = 0.45;
  nfig=100;
  demo=false;
end 

% caoutchouc
mu= E/(2*(1+nu));
lambda = E*nu/((1+nu)*(1-2*nu));
isolines=false;
%  

fprintf('------------------------------------------------------\n'); 
fprintf('      2D elasticity eBVP on [0,1]x[0,1]\n');
fprintf('         using hypercube mesh\n\n');
fprintf('             -div(sigma(u)) = k*u \n');
fprintf(' and boundary conditions :\n');
fprintf('   * Dirichlet on [1,2,3,4]\n');
fprintf('       u_1 = u_2 = 0 \n');
fprintf(' with lambda=%g, mu=%g\n',lambda,mu);
fprintf('------------------------------------------------------\n'); 
tstart=tic();
dim=2;
Th=fc_simesh.HyperCube(dim,N);
T(1)=toc(tstart);
fprintf('*** Generate and read mesh file in : %.3f(s)\n',T(1));
info(Th);

tstart=tic();
Hop=Hoperator();
Hop.opStiffElas(dim,lambda,mu);
pde=PDEelt(Hop);
bvp=BVP(Th,pde);
for lab=Th.sThlab(Th.find(1)), bvp.setDirichlet( lab, 0.,1:2);end
T(2)=toc(tstart);
fprintf('*** Set eBVP in : %.3f(s)\n',T(2));

% Computation of numerical eigenvectors and eigenvalues
tstart=tic();
[eVec,eVal,flag]=fc_vfemp1.addon.eigs.solve(bvp,NumEigs,sigma);
T(3)=toc(tstart);
if flag~=0, warning('function eigs trouble: not all eigenvalues converged!');end
fprintf('*** Solve eBVP with %d eigenvalues in : %.3f(s)\n',NumEigs,T(3));

tstart=tic();
[eVec,eVal]=fc_vfemp1.addon.eigs.splitsort(bvp,eVec,eVal);
fc_vfemp1.addon.eigs.plot(Th,eVec,eVal,'nfig',nfig,'demo',demo)
drawnow
T(4)=toc(tstart);
fprintf('*** Graphical representations in : %.3f(s)\n',T(4));

if nfig>0
  figure(1)
  Th.plotmesh('color',0.9*[1,1,1])
  hold on
  axis image
  Th.plotmesh('d',1,'legend',true,'linewidth',2)
end