%clear all
close all
if ~exist('NumEigs','var')
  NumEigs=10; % Number of eigenvalues (and eigenvectors) to find
end
L=2; % integer
H=3; % integer
I=1:NumEigs; %

LN=[75,100:50:400];
%LN=[75,100:50:200];
nLN=length(LN);
iN=1;
eVecL2=zeros(nLN,NumEigs);
eVecH1=zeros(nLN,NumEigs);
eVal=zeros(nLN,NumEigs);
for N=LN
  Th=fc_simesh.HyperCube(2,[L*N,H*N],'trans',@(q) [L*q(1,:);H*q(2,:)]);
  %tcpu(1)=toc(tstart);
  fprintf('     Mesh sizes : nq=%d\n',Th.nq);
  dim=2;d=2;
  Lop=Loperator(dim,d,{1,0;0,1},[],[],[]);
  pde=PDEelt(Lop);
  bvp=BVP(Th,pde);
  for lab=1:4
    bvp.setDirichlet( lab, 0);
  end

  [numEigsVec,numEigsVal,flag]=fc_vfemp1.addon.eigs.solve(bvp,NumEigs,'sm');
  if flag~=0, warning('function eigs trouble: not all eigenvalues converged!');end
  
  
  % Computation of exacts eigenvectors and eigenvalues
  [exEigsVec,exEigsVal]=fc_vfemp1.addon.eigs.samples_2d.LaplacianEigenOnRectangle(Th,L,H,NumEigs);
  
  % Error computation
  [numEigsVec,numEigsVal]=fc_vfemp1.addon.eigs.splitsort(bvp,numEigsVec,numEigsVal);
  [eVecL2(iN,:),eVecH1(iN,:),eVal(iN,:)]=fc_vfemp1.addon.eigs.errors(Th,numEigsVec,numEigsVal,exEigsVec,exEigsVal);
  Lh(iN)=Th.get_h();
  iN=iN+1;
end

options=fc_tools.graphics.DisplayFigures('nfig',3);
loglog_opt={'Linewidth',2};
interpreter=@(s) fc_tools.graphics.interpreter(s);
%options={'interpreter','latex','fontsize',12};
figure(1)
RGBcolors = fc_tools.graphics.selectColors(NumEigs);
for i=1:NumEigs
  loglog(Lh,eVal(:,i),'Color',RGBcolors(i,:),loglog_opt{:});
  hold on
  cLegend{i}=sprintf(interpreter('$\\lambda_{%d}=%.2f$'),i,exEigsVal(i));
end
loglog(Lh,Lh.^2,'-dk',loglog_opt{:});
cLegend{NumEigs+1}=interpreter('$O(h^2)$');
legh=legend(cLegend);
set(legh,options.legend{:},options.interpreter{:})
xlabel('h')
ylabel('errors')
title('Eigenvalues : relative errors',options.title{:},options.interpreter{:})

figure(2)
for i=1:NumEigs
  loglog(Lh,eVecH1(:,i),'Color',RGBcolors(i,:),loglog_opt{:});
  hold on
  cLegend{i}=interpreter(sprintf('$\\lambda_{%d}=%.2f$',i,exEigsVal(i)));
end
loglog(Lh,Lh.^2,'-dk',loglog_opt{:});
cLegend{NumEigs+1}=interpreter('$O(h^2)$');
legh=legend(cLegend);
set(legh,options.legend{:},options.interpreter{:})
xlabel('h')
ylabel('errors')
title(interpreter('Eigenfunctions : relative errors in $H^1$-norm'),options.title{:},options.interpreter{:})
figure(3)
for i=1:NumEigs
  loglog(Lh,eVecL2(:,i),'Color',RGBcolors(i,:),loglog_opt{:});
  hold on
  cLegend{i}=interpreter(sprintf('$\\lambda_{%d}=%.2f$',i,exEigsVal(i)));
end
loglog(Lh,Lh.^2,'-dk',loglog_opt{:});
cLegend{NumEigs+1}=interpreter('$O(h^2)$');
legh=legend(cLegend);
set(legh,options.legend{:},options.interpreter{:})
xlabel('h')
ylabel('errors')
title(interpreter('Eigenfunctions : relative errors in $L^2$-norm'),options.title{:},options.interpreter{:})